@@ -169,17 +169,6 @@ class AppDataSet(ORMBase):
         session.add_all(objects)
         session.flush()
 
-    def user_is_previewing_app(self):
-        """Determine if the current user is using a preview subscription. The example below shows how you might use this:
-
-        .. literalinclude:: ../../../tropofy_example_apps/core_dependencies/facility_location/facility_location.py
-           :language: python
-           :pyobject: ExecuteSolverFunction.execute_function
-
-        """
-        request = threadlocal.get_current_request()
-        result = post_to_gui_server(request.registry.settings.get('custom.gui_server_url') + "/user_is_previewing_app/" + request.app.url_name, {})
-        return result.json()['user_is_previewing_app']
 
     def query(self, *args):
         """Returns an SQLAlchemy :class:`Query` object for the Data Set.  The example below
