@@ -31,7 +31,7 @@ class ExecuteFunction(Widget):
     def get_type(self):
         return "ExecuteFunctionWidget"
 
-    def refresh_from_db(self, data_set):
+    def refresh_from_db(self, data_set, request):
         return {'last_run_messages': data_set.execute_function_info.last_run_messages}
 
     def _set_optimisation_as_started(self, data_set):
