@@ -69,9 +69,10 @@ class SimpleGrid(GridWidget):
         return edited_obj.as_json_data_row(self.get_grids_column_names())
 
     def get_filtered_refresh_objects(self, data_set, display_start, display_length, global_search_field, ordered_col_name_sort_direction_tuples):
-        if not data_set:
+        try:
+            qry = self.get_qry_of_non_filtered_refresh_objects(data_set)
+        except AttributeError:
             return [], 0, 0
-        qry = self.get_qry_of_non_filtered_refresh_objects(data_set)
         total_records_before_filtering = qry.count()
 
         #Filter from search
